@@ -3,4 +3,4 @@ from kumuniverse import unleash
 from kumuniverse import dynamodb
 from kumuniverse import malacanang_api
 from kumuniverse import taho_api
-from kumuniverse import kafka_msk
+from kumuniverse import k8s_model_api
