@@ -573,6 +573,7 @@ class SagemakerFeatureStore:
         feature_group_name: str,
         paritioned_spark_df: SparkDataFrame,
         thread_num: int = 10,
+        redis_ops_limit: int = 3200,
         redis_expiration: int = 604800,
     ):
         """
@@ -602,6 +603,7 @@ class SagemakerFeatureStore:
             redis_config,
             ingest_to_aws,
             thread_num=10,
+            redis_ops_limit=3200,
             redis_expiration=604800,
         ):
             if redis_config:
@@ -675,7 +677,9 @@ class SagemakerFeatureStore:
                 max_workers=thread_num
             ) as executor:
                 futures = [
-                    executor.submit(ingest_worker, chunked_rows, feature_group_name)
+                    executor.submit(
+                        ingest_worker, chunked_rows, feature_group_name, redis_ops_limit
+                    )
                     for chunked_rows in chunked_rows_list
                 ]
                 for future in concurrent.futures.as_completed(futures):
@@ -715,6 +719,7 @@ class SagemakerFeatureStore:
                     redis_config,
                     ingest_to_aws,
                     thread_num,
+                    redis_ops_limit,
                     redis_expiration,
                 )
             )
@@ -722,7 +727,11 @@ class SagemakerFeatureStore:
             raise Exception("ERROR:", e)
 
     def ingest_batch_online(
-        self, feature_group_name: str, data: List[dict], redis_expiration: int = 604800
+        self,
+        feature_group_name: str,
+        data: List[dict],
+        redis_ops_limit: int = 3200,
+        redis_expiration: int = 604800,
     ):
         """
         Ingests a list of dictionaries to the feature group's online store. Limited to <=100 records per call.
@@ -804,7 +813,7 @@ class SagemakerFeatureStore:
                 # expire for 7 days (default)
                 pipe.expire(key_name, redis_expiration)
                 ops_ctr = ops_ctr + 1
-                if ops_ctr == 3200:
+                if ops_ctr == redis_ops_limit:
                     time.sleep(1 * (0.8 + random.random() * 0.4))
                     pipe.execute()
                     # Reset
